@@ -928,7 +928,7 @@ class Statusbar:
 
     def show_message(self, title, msg, msg_type):
         if title and msg:
-            text = "{}: {}".format(title, msg)
+            text = f"{title}: {msg}"
         else:
             text = title or msg
         self._show_text(text)
